/* xgetopt.h - Similar behaviour to getopt and getopt_long, but not an
 *             attempt to emulate those exactly.
 *
 * Copyright (C) 2013, 2020 Timothy Richard Musson
 *
 * Email: Tim Musson <trmusson@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


#ifndef HAVE_XGETOPT_H
#define HAVE_XGETOPT_H

#ifndef XGETOPT_SENSITIVE
#define XGETOPT_SENSITIVE         FALSE
#endif

#define XGETOPT_MISSING_ARG      -3
#define XGETOPT_UNKNOWN          -2
#define XGETOPT_NONE             -1


/* min_len specifies how many characters it takes to differentiate this
   option from another with the same initial characters - e.g. width vs
   window takes 3 chars to avoid ambiguity. */

struct _XGetOption {
#if XGETOPT_SENSITIVE
	int     min_len;
#else
	int     min_len_short; /* For the short form. */
	int     min_len_long;  /* For the long form.  */
#endif
	xbool_t requires_arg;
	char    *opt_str;
};

typedef struct  _XGetOption XGetOption;

int             xgetopt (int argc, char *argv[], int *idx,
                         XGetOption *option, int n_options);

#endif /* HAVE_XGETOPT_H */

