/* xmem.c - Basic memory utilities based on glibc-doc examples.
 *
 * Copyright (C) 2005, 2020 Timothy Richard Musson
 *
 * Email: Tim Musson <trmusson@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

#include <stdio.h>
#include <stdlib.h>

#ifndef XMEM_H
#include "xmem.h"
#endif



void*
xmalloc (size_t size)
{
	void *p;

	p = malloc (size);
	if (p == NULL) {
		fprintf (stderr, "xmalloc: out of memory\n");
		exit (EXIT_FAILURE);
	}
	return p;
}


void*
xcalloc (size_t nmemb, size_t size)
{
	void *p;

	p = calloc (nmemb, size);
	if (p == NULL) {
		fprintf (stderr, "xcalloc: out of memory\n");
		exit (EXIT_FAILURE);
	}
	return p;
}


void*
xrealloc (void *p, size_t size)
{
	void *p_new;

	p_new = realloc (p, size);
	if (p_new == NULL) {
		fprintf (stderr, "xrealloc: out of memory\n");
		exit (EXIT_FAILURE);
	}
	return p_new;
}


void
xfree (void *p)
{
	if (p != NULL) {
		free (p);
	}
}

